#ifndef MY_BODY_HH
#define MY_BODY_HH

#include <dune/common/fvector.hh>

#include <dune/tectonic/body.hh>

#include "mygeometry.hh"

template <int dimension> class MyBody : public Body<dimension> {
  using typename Body<dimension>::ScalarFunction;
  using typename Body<dimension>::VectorField;

public:
  MyBody(Dune::ParameterTree const &parset, MyGeometry const &mygeometry)
      : poissonRatio_(parset.get<double>("body.poissonRatio")),
        youngModulus_(parset.get<double>("body.youngModulus")),
        shearViscosity_(parset.get<double>("body.shearViscosity")),
        bulkViscosity_(parset.get<double>("body.bulkViscosity")),
        density_(parset.get<double>("body.density")),
        gravity_(parset.get<double>("gravity")) {}

  double getPoissonRatio() const override { return poissonRatio_; }

  double getYoungModulus() const override { return youngModulus_; }

  double getShearViscosity() const override { return shearViscosity_; }
  double getBulkViscosity() const override { return bulkViscosity_; }

  double getDensity() const override { return density_; }
  double getGravity() const override { return gravity_; }

private:
  double const poissonRatio_;
  double const youngModulus_;
  double const shearViscosity_;
  double const bulkViscosity_;
  double const density_;
  double const gravity_;
};

#endif
